aboutsummaryrefslogtreecommitdiffhomepage
path: root/isar/isar-find-theorems.el
diff options
context:
space:
mode:
authorGravatar David Aspinall <da@inf.ed.ac.uk>2009-09-15 07:47:15 +0000
committerGravatar David Aspinall <da@inf.ed.ac.uk>2009-09-15 07:47:15 +0000
commit682b4c17840aaa694cf3c7684bb5b06bcb4108c2 (patch)
tree4eced173d60c3a2c2d81d7c2850364a2d8d06332 /isar/isar-find-theorems.el
parentb8bdbab2356aa0e68164143d3f78c73ad12197c7 (diff)
Fix compile errors
Diffstat (limited to 'isar/isar-find-theorems.el')
-rw-r--r--isar/isar-find-theorems.el32
1 files changed, 18 insertions, 14 deletions
diff --git a/isar/isar-find-theorems.el b/isar/isar-find-theorems.el
index 0d40f392..15da9f67 100644
--- a/isar/isar-find-theorems.el
+++ b/isar/isar-find-theorems.el
@@ -10,6 +10,23 @@
;; $Id$
;;
+(require 'pg-vars)
+(declare-function proof-find-theorems "pg-user")
+
+
+;; search form field values
+
+(defvar isar-find-theorems-data (list
+ "" ;; num
+ "" ;; pattern
+ "none" ;; intro
+ "none" ;; elim
+ "none" ;; dest
+ "" ;; name
+ "" ;; simp
+ )
+ "Values of the Find Theorems search form's fields.")
+
;; make the original (minibuffer based) "Find theorems" command (from
;; ../generic/pg-user.el) available as isar-find-theorems-minibuffer;
;; return '(nil) so that isar-find-theorems-minibuffer works as a
@@ -35,7 +52,7 @@
(apply 'isar-find-theorems-create-searchform isar-find-theorems-data)
'(nil))
;; update the universal key bindings (see ../generic/proof-config.el)
;;
;; C-c C-a C-m is bound to isar-find-theorems-minibuffer
;; C-c C-a C-f is bound to isar-find-theorems-form
@@ -69,19 +86,6 @@
;; matching the current goal as introduction rule and not having "HOL."
;; in their name (i.e. not being defined in theory HOL).
-;; search form field values
-
-(defvar isar-find-theorems-data (list
- "" ;; num
- "" ;; pattern
- "none" ;; intro
- "none" ;; elim
- "none" ;; dest
- "" ;; name
- "" ;; simp
- )
- "Values of the Find Theorems search form's fields.")
-
;; search form widgets (set in isar-find-theorems-create-searchform
;; and accessed in the "Find" handler)
@@ -35,7 +52,7 @@
(apply 'isar-find-theorems-create-searchform isar-find-theorems-data)
'(nil))
-;; update the universal key bindings (see ../generic/proof-config.el)
+;; update the universal key bindings (see ../generic/pg-vars.el)
;;
;; C-c C-a C-m is bound to isar-find-theorems-minibuffer